=======
History
=======

0.3.0 (2017-10-07)
------------------

* First release on PyPI.

0.2 (2017-10-07)
------------------

* Checkpoint of the last version working with 2.x. This checkpoint contains code from many years ago.
